==> haskell-src-exts-util-0.2.5-418-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-exts-util.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-exts-util
version:              0.2.5
visibility:           public
id:                   haskell-src-exts-util-0.2.5-7XtyN5ZtvPx7FJjPBRhc3J
key:                  haskell-src-exts-util-0.2.5-7XtyN5ZtvPx7FJjPBRhc3J
license:              BSD-3-Clause
copyright:            All Rights Reserved
maintainer:           pepeiborra@gmail.com
author:               Neil Mitchell, Jose Iborra
homepage:             https://github.com/pepeiborra/haskell-src-exts-util
synopsis:             Helper functions for working with haskell-src-exts trees
description:          Helper functions for working with haskell-src-exts trees.
category:             language
abi:                  315782d2334be1fef4dda13fede9c785
exposed:              True
exposed-modules:      Language.Haskell.Exts.Util
hidden-modules:
    Language.Haskell.Exts.Bracket Language.Haskell.Exts.FreeVars
    Language.Haskell.Exts.Util.Internal Paths_haskell_src_exts_util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-util-0.2.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-util-0.2.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-util-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-exts-util
hs-libraries:         HShaskell-src-exts-util-0.2.5-7XtyN5ZtvPx7FJjPBRhc3J
depends:
    base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd
    haskell-src-exts-1.23.1-IJp3jGoQkeD6bKOJwDjwr2 transformers-0.5.6.2
    uniplate-1.6.13-2iywHCEvZoZFp9V7vozV4V

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-util/html/haskell-src-exts-util.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-util/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-exts-util-0.2.5-419-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-src-exts-util.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-exts-util
version:              0.2.5
visibility:           public
id:                   haskell-src-exts-util-0.2.5-iuN2uCy2r4I1lmzmk6H6w
key:                  haskell-src-exts-util-0.2.5-iuN2uCy2r4I1lmzmk6H6w
license:              BSD-3-Clause
copyright:            All Rights Reserved
maintainer:           pepeiborra@gmail.com
author:               Neil Mitchell, Jose Iborra
homepage:             https://github.com/pepeiborra/haskell-src-exts-util
synopsis:             Helper functions for working with haskell-src-exts trees
description:          Helper functions for working with haskell-src-exts trees.
category:             language
abi:                  c7f7ce7ad36f6a15c3495ceedbb28aeb
exposed:              True
exposed-modules:      Language.Haskell.Exts.Util
hidden-modules:
    Language.Haskell.Exts.Bracket Language.Haskell.Exts.FreeVars
    Language.Haskell.Exts.Util.Internal Paths_haskell_src_exts_util

import-dirs:          /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-util-0.2.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-util-0.2.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/haskell-src-exts-util-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-exts-util
hs-libraries:         HShaskell-src-exts-util-0.2.5-iuN2uCy2r4I1lmzmk6H6w
depends:
    base-4.17.2.1 containers-0.6.7
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd
    haskell-src-exts-1.23.1-CzJQ5zGnCXZBMuis4DH9jH transformers-0.5.6.2
    uniplate-1.6.13-3snp4uiQljo8GPYgxrrecr

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-util/html/haskell-src-exts-util.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-util/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
